/***************************************************************************
 *   Copyright (C) 2004-2005 by Jürgen Kofler                                   *
 *   kaffeine@gmx.net                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
 ***************************************************************************/

/*
 * Last modified: $Date: 2005/09/03 09:36:41 $ by $Author: juergenk $
 */

#ifndef _KAFFEINEPART_H_
#define _KAFFEINEPART_H_


#include <kparts/factory.h>

#include <qtimer.h>

#include "kmediapart.h"
#include "kaffeine_part_iface.h"

#define FORWARD_TIMER 0
#define BACKWARD_TIMER 1

class QWidget;
class QSlider;
class QLabel;
class QPushButton;
class MRL;
class KXineWidget;
class QPoint;
class KSelectAction;
class KToggleAction;
class Equalizer;
class VideoSettings;
class FilterDialog;
class PositionSlider;
class KProgressDialog;
class KPopupMenu;

/**
 * Kaffeine Part - xine based player part
 * @author Jürgen Kofler <kaffeine@gmx.net>
 *
 */
class KaffeinePart : public virtual KMediaPart, public virtual KaffeinePartIface
{
	Q_OBJECT
public:
	KaffeinePart(QWidget*, const char*, QObject*, const char*, const QStringList&);
	virtual ~KaffeinePart();

	/*
	 *Reimplemented from KMediaPart
	 */
	virtual bool isPlaying();
	virtual bool isPaused();
	virtual void audiocdMRLS(MRL::List& mrls, bool& ok, bool& supported, const QString& device);
	virtual void vcdMRLS(MRL::List& mrls, bool& ok, bool& supported, const QString& device);
	virtual void dvdMRLS(MRL::List& mrls, bool& ok, bool& supported, const QString& device);
	virtual bool hasChapters(); /* e.g. DVD */
	virtual bool hasVideo();
	virtual void playNextChapter();
	virtual void playPreviousChapter();
	virtual QString supportedExtensions();
	virtual void* engine();
	virtual uint volume() const; /* percent */
	virtual uint position() const; /* percent */

	virtual bool closeURL(); /* stops playback and shows kaffeine logo */
	static KAboutData* createAboutData();

	/*
	 * DCOP functions...
	 */
	virtual int getContrast();
	virtual void setContrast(int c);
	virtual int getBrightness();
	virtual void setBrightness(int b);
	virtual void dvdMenuUp();
	virtual void dvdMenuDown();
	virtual void dvdMenuLeft();
	virtual void dvdMenuRight();
	virtual void dvdMenuSelect();
	virtual void dvdMenuToggle();
	virtual void aspectRatioAuto();
	virtual void aspectRatio4_3();
	virtual void aspectRatioAnamorphic();
	virtual void aspectRatioSquare();
	virtual void aspectRatioDVB();
	virtual void zoomIn();
	virtual void zoomOut();
	virtual void zoomOff();

public slots:
	/*
	 * Reimplemented from KMediaPart
	 */
	virtual bool openURL(const MRL& mrl);
	virtual void slotPrepareForFullscreen(bool);
	virtual void slotPlay(bool forcePlay=false);
	virtual void slotTogglePause(bool pauseLive=true);
	virtual void slotSetVolume(uint); /* percent */
	virtual void slotSetPosition(uint); /* percent */
	virtual void slotSyncVolume();
	virtual void slotStop();
	virtual void slotMute(); /* toggle mute */

	virtual void slotVolumeUp();
	virtual void slotVolumeDown();
	virtual void slotPosPlusSmall();
	virtual void slotPosMinusSmall();
	virtual void slotPosPlusMedium();
	virtual void slotPosMinusMedium();
	virtual void slotPosPlusLarge();
	virtual void slotPosMinusLarge();
	virtual void slotJumpIncrement(int);

	/***************** Private ********************/

private slots:
	virtual void slotFinalize();
	virtual void slotTrackPlaying();
	virtual void slotCheckMoved();
	virtual void slotNext();
	virtual void slotPrevious();
	virtual void slotSaveStream();
	virtual void slotChannelInfo(const QStringList&, const QStringList&, int, int);
	virtual void slotSetSubtitle(int);
	virtual void slotSetAudioChannel(int);
	virtual void slotNewPosition(int, const QTime&);
	virtual void slotVolumeChanged(int);
	virtual void slotPictureSettings();
	virtual void slotEqualizer();
	virtual void slotDeinterlaceQuality();
	virtual void slotFilterDialog();
	virtual void slotInfo();
	virtual void slotToggleBroadcastSend();
	virtual void slotBroadcastReceive();
	virtual void slotJumpToPosition();
	virtual void slotButtonTimerPressed();
	virtual void slotButtonTimerReleased();
	virtual void slotToggleOsdTimer();
	virtual void slotScreenshot();
	virtual void slotConfigXine();
	virtual void slotError(const QString&);
	virtual void slotMessage(const QString&);
	virtual void slotStatus(const QString&);
	virtual void slotNewTitle();
	virtual void slotNewLength();
	virtual void slotNewFrameSize();
	virtual void slotPlaybackFinished();
	virtual void slotContextMenu(const QPoint&);
	virtual void slotDisableAllActions();
	virtual void slotEnableAllActions();
	virtual void slotEnablePlayActions();
	virtual void slotCopyToClipboard();
	virtual void slotLaunchExternally();
	virtual void slotLaunchDelayed();
	virtual void slotFastForward();
	virtual void slotSlowMotion();

private:
	virtual void initActions();
	virtual void initConnections();
	virtual void loadConfig();
	virtual void saveConfig();

private:
	QString m_hrefParam;
	bool m_autoStart;
	bool m_imageWindow;
	QPoint m_oldPosition;
	QTimer m_posCheckTimer;
	QTimer m_osdTimerEnabler;  /* Provide Long click on timer button */
	bool m_isOsdTimer;  /* Status of Osd Timer (on/off) */
	int m_timerDirection;  /* Counting Up or Down */

	MRL::List m_playlist;
	uint m_current;
	uint m_lastDeinterlaceQuality;
	QString m_lastDeinterlacerConfig;
	uint m_broadcastPort;
	QString m_broadcastAddress;

	QSlider* m_volume;
	PositionSlider* m_position;
	QPushButton* m_playTime;

	KSelectAction* m_audioChannels;
	KSelectAction* m_audioVisual;
	KSelectAction* m_subtitles;
	KToggleAction* m_deinterlaceEnabled;
	KToggleAction* m_broadcastSend;
	KToggleAction* m_pauseButton;

	KXineWidget* m_xine;
	VideoSettings* m_pictureSettings;
	Equalizer* m_equalizer;
	QWidget* m_deinterlacerConfigWidget;
	FilterDialog* m_filterDialog;

	KPopupMenu* m_embeddedContext;

	/*  dvb  */
public:
	QString TimeShiftFilename;

public slots:
	virtual void slotDvbOpen( const QString &filename, const QString &chanName, int haveVideo );
	virtual void getTimeShiftFilename( const QString &filename );
	virtual void requestForOSD( const QString &text, int duration, int priority );
	virtual void setDvbCurrentNext( const QStringList &list );

signals:
	virtual void stopDvb();
	virtual void playerPause();
};

#include <qslider.h>

class VolumeSlider : public QSlider
{

public:
	VolumeSlider();
	virtual ~VolumeSlider();

protected:
	virtual void wheelEvent(QWheelEvent* e);
	virtual bool eventFilter(QObject *obj, QEvent *ev);
};




#endif // _KAFFEINEPART_H_
