/***************************************************************************
 *   Copyright (C) 2004-2005 by Jürgen Kofler                                   *
 *   kaffeine@gmx.net                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
 ***************************************************************************/

 /*
  * Last modified: $Date: 2005/09/03 09:36:40 $ by $Author: juergenk $
  */

#include <qstring.h>
#include <qstringlist.h>

#include "mrl.h"

MRL::MRL()
  : m_url(QString::null),
  m_kurl(KURL()),
  m_title(QString::null),
  m_artist(QString::null),
  m_album(QString::null),
  m_track(QString::null),
  m_year(QString::null),
  m_genre(QString::null),
  m_comment(QString::null),
  m_mime(QString::null),
  m_length(),
  m_subtitleFiles(),
  m_currentSubtitle(-1)
{
  reset();
}

MRL::MRL(const KURL& url, const QString& title, const QTime& length,
		const QString& mime, const QString& artist,
		const QString& album, const QString& track,
		const QString& year, const QString& genre,
		const QString& comment, const QStringList& subtitleFiles,
		int currentSubtitle)
  : m_url(url.prettyURL()),
  m_kurl(url),
  m_title(title),
  m_artist(artist),
  m_album(album),
  m_track(track),
  m_year(year),
  m_genre(genre),
  m_comment(comment),
  m_mime(mime),
  m_length(length),
  m_subtitleFiles(subtitleFiles),
  m_currentSubtitle(currentSubtitle)
{
}

MRL::MRL(const QString& url, const QString& title, const QTime& length,
		const QString& mime, const QString& artist,
		const QString& album, const QString& track,
		const QString& year, const QString& genre,
		const QString& comment, const QStringList& subtitleFiles,
		int currentSubtitle)
  : m_url(url),
  m_kurl(KURL::fromPathOrURL(url)),
  m_title(title),
  m_artist(artist),
  m_album(album),
  m_track(track),
  m_year(year),
  m_genre(genre),
  m_comment(comment),
  m_mime(mime),
  m_length(length),
  m_subtitleFiles(subtitleFiles),
  m_currentSubtitle(currentSubtitle)
{
}

MRL::~MRL()
{
}

MRL::List::List(const QString& url)
{
  append(url);
}
/*
MRL::List::List(const KURL& url)
{
  append(url);
}
*/

MRL::List::List(const QStringList& list)
{
	QStringList::ConstIterator end( list.begin());
  for (QStringList::ConstIterator it = list.begin(); it != end; ++it)
    append( *it );
}

/*
MRL::List::List(const KURL::List& list)
{
  for (KURL::List::ConstIterator it = list.begin(); it != list.end(); it++)
    append( *it );
}
*/

QStringList MRL::List::toStringList() const
{
  QStringList list;
  MRL::List::ConstIterator end(begin());
  for (MRL::List::ConstIterator it = begin(); it != end; ++it)
    list.append( (*it).url() );

  return list;
}

void MRL::reset()
{
  m_url = QString::null; m_kurl = KURL();
}

bool MRL::isEmpty() const { return (m_url == QString::null); }

QString& MRL::url() { return m_url; }
const QString& MRL::url() const { return m_url; }

KURL& MRL::kurl() { return m_kurl; }
const KURL& MRL::kurl() const { return m_kurl; }

QString& MRL::title() { return m_title; }
const QString& MRL::title() const { return m_title; }

QString& MRL::artist() { return m_artist; }
const QString& MRL::artist() const { return m_artist; }

QString& MRL::album() { return m_album; }
const QString& MRL::album() const { return m_album; }

QString& MRL::track() { return m_track; }
const QString& MRL::track() const { return m_track; }

QString& MRL::year() { return m_year; }
const QString& MRL::year() const { return m_year; }

QString& MRL::genre() { return m_genre; }
const QString& MRL::genre() const { return m_genre; }

QString& MRL::comment() { return m_comment; }
const QString& MRL::comment() const { return m_comment; }

QString& MRL::mime() { return m_mime; }
const QString& MRL::mime() const { return m_mime; }

QTime& MRL::length() { return m_length; }
const QTime& MRL::length() const { return m_length; }

QStringList& MRL::subtitleFiles() { return m_subtitleFiles; }
const QStringList& MRL::subtitleFiles() const { return m_subtitleFiles; }

int MRL::currentSubtitle() const { return m_currentSubtitle; }

void MRL::setURL(const QString& url) { m_url = url; m_kurl = KURL(url); }
void MRL::setTitle(const QString& title) { m_title = title; }
void MRL::setArtist(const QString& artist) { m_artist = artist; }
void MRL::setAlbum(const QString& album) { m_album = album; }
void MRL::setTrack(const QString& track) { m_track = track; }
void MRL::setYear(const QString& year) { m_year = year; }
void MRL::setGenre(const QString& genre) { m_genre = genre; }
void MRL::setComment(const QString& comment) { m_comment = comment; }
void MRL::setMime(const QString& mime) { m_mime = mime; }
void MRL::setLength(const QTime& length) { m_length = length; }
void MRL::setSubtitleFiles(const QStringList& urls) { m_subtitleFiles = urls; }
void MRL::addSubtitleFile(const QString& url) { m_subtitleFiles.append(url); }
void MRL::setCurrentSubtitle(int sub) { m_currentSubtitle = sub; }


